@@ -201,8 +201,9 @@ class Validator:
                                         valid_apertures, value, contrast_curve_file)
                          for value in range(0, scenarios)]
         logging.info("Start validation processes")
-        with Pool(processes=cpus) as pool:
-            validation_results = pool.map(input_n_times)
+        #TODO fix usage of cpus returning same value for all executions
+        with Pool(processes=1) as pool:
+            validation_results = pool.map(TriceratopsThreadValidator.validate, input_n_times)
         logging.info("Finished validation processes")
         fpp_sum = 0
         fpp2_sum = 0
@@ -447,7 +448,7 @@ class TriceratopsThreadValidator:
         @param input: ValidatorInput
         @return: the FPP values, the probabilities dataframe and additional target values.
         """
-        input.target.calc_depths(tdepth=input.depth, all_ap_pixels=input.apertures)
+        #input.target.calc_depths(tdepth=input.depth, all_ap_pixels=input.apertures)
         input.target.calc_probs(time=input.time, flux_0=input.flux, flux_err_0=input.sigma, P_orb=input.period,
                                 contrast_curve_file=input.contrast_curve, parallel=True)
         fpp2 = 1 - 25 * (1 - input.target.FPP) / (25 * (1 - input.target.FPP) + input.target.FPP)
